==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'THÊM TÀI LIỆU', # MODIF
	'bouton_ajouter_image' => 'THÊM HÌNH', # MODIF

	// D
	'double_clic_inserer_doc' => 'Nhấp chuột hai lần để thêm lối tắt này vào khung chữ',

	// E
	'entree_dimensions' => 'Khổ:',
	'entree_titre_document' => 'Tựa bài hồ sơ:',
	'entree_titre_image' => 'Tựa đề hình:',

	// I
	'image_tourner_180' => 'Xoay 180°',
	'image_tourner_droite' => 'Xoay qua phải 90°',
	'image_tourner_gauche' => 'Xoay qua trái 90°',
	'info_document' => 'Tài liệu ',
	'info_document_indisponible' => 'Tài liệu này không có',
	'info_documents' => 'Tài liệu',
	'info_inclusion_directe' => 'Gộp vào trực tiếp:',
	'info_inclusion_vignette' => 'Gộp các hình nhỏ xem trước:',
	'info_installer_tous_documents' => 'Cài đặt tất cả tài liệu',
	'info_logo_max_taille' => 'Hồ sơ này phải nhỏ hơn @maxi@ (hồ sơ này là @actuel@).',
	'info_portfolio' => 'Tập hồ sơ',
	'info_referencer_doc_distant' => 'Nối kết với một tài liệu trên internet:',
	'info_telecharger' => 'Đem/tải lên từ máy bạn:',

	// T
	'texte_documents_joints' => 'Bạn có thể cho phép đính kèm thêm các tài liệu (hồ sơ, hình ảnh, v.v...) vào các bài vở và/hoặc đề mục. Những hồ sơ này có thể được nối kết trong bài hoặc hiện riêng ra.', # MODIF
	'texte_documents_joints_2' => 'LƯU Ý: Bố trí hiện nay không ngăn ngừa việc nhét hình trực tiếp vào bài vở.', # MODIF
	'titre_documents_joints' => 'Tài liệu đính kèm',
	'tout_dossier_upload' => 'Tất cả hồ sơ @upload@',

	// U
	'upload_fichier_zip' => 'Hồ sơ ZIP',
	'upload_fichier_zip_texte' => 'Hồ sơ bạn tính thiết trí là hồ sơ ZIP.',
	'upload_fichier_zip_texte2' => 'Hồ sơ này có thể:',
	'upload_limit' => 'Hồ sơ này quá to cho server; khổ lớn nhất cho phép <i>đem lên</i> là @max@.',
	'upload_zip_decompacter' => 'được mở ra và hồ sơ trong đó sẽ được thiết trí vào trang web. Các hồ sơ sẽ được thiết trí là:',
	'upload_zip_telquel' => 'thiết trí y nguyên, hồ sơ ZIP;'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=vi
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'THÊM TÀI LIỆU', # MODIF
	'bouton_ajouter_image' => 'THÊM HÌNH', # MODIF

	// D
	'double_clic_inserer_doc' => 'Nhấp chuột hai lần để thêm lối tắt này vào khung chữ',

	// E
	'entree_dimensions' => 'Khổ:',
	'entree_titre_document' => 'Tựa bài hồ sơ:',
	'entree_titre_image' => 'Tựa đề hình:',

	// I
	'image_tourner_180' => 'Xoay 180°',
	'image_tourner_droite' => 'Xoay qua phải 90°',
	'image_tourner_gauche' => 'Xoay qua trái 90°',
	'info_document' => 'Tài liệu ',
	'info_document_indisponible' => 'Tài liệu này không có',
	'info_documents' => 'Tài liệu',
	'info_inclusion_directe' => 'Gộp vào trực tiếp:',
	'info_inclusion_vignette' => 'Gộp các hình nhỏ xem trước:',
	'info_installer_tous_documents' => 'Cài đặt tất cả tài liệu',
	'info_logo_max_taille' => 'Hồ sơ này phải nhỏ hơn @maxi@ (hồ sơ này là @actuel@).',
	'info_portfolio' => 'Tập hồ sơ',
	'info_referencer_doc_distant' => 'Nối kết với một tài liệu trên internet:',
	'info_telecharger' => 'Đem/tải lên từ máy bạn:',

	// T
	'texte_documents_joints' => 'Bạn có thể cho phép đính kèm thêm các tài liệu (hồ sơ, hình ảnh, v.v...) vào các bài vở và/hoặc đề mục. Những hồ sơ này có thể được nối kết trong bài hoặc hiện riêng ra.', # MODIF
	'texte_documents_joints_2' => 'LƯU Ý: Bố trí hiện nay không ngăn ngừa việc nhét hình trực tiếp vào bài vở.', # MODIF
	'titre_documents_joints' => 'Tài liệu đính kèm',
	'tout_dossier_upload' => 'Tất cả hồ sơ @upload@',

	// U
	'upload_fichier_zip' => 'Hồ sơ ZIP',
	'upload_fichier_zip_texte' => 'Hồ sơ bạn tính thiết trí là hồ sơ ZIP.',
	'upload_fichier_zip_texte2' => 'Hồ sơ này có thể:',
	'upload_limit' => 'Hồ sơ này quá to cho server; khổ lớn nhất cho phép <i>đem lên</i> là @max@.',
	'upload_zip_decompacter' => 'được mở ra và hồ sơ trong đó sẽ được thiết trí vào trang web. Các hồ sơ sẽ được thiết trí là:',
	'upload_zip_telquel' => 'thiết trí y nguyên, hồ sơ ZIP;',
];
